@@ -11,6 +11,7 @@ from .rewrite.rewrite_import_plutusdata import RewriteImportPlutusData
 from .rewrite.rewrite_import_typing import RewriteImportTyping
 from .rewrite.rewrite_inject_builtins import RewriteInjectBuiltins
 from .rewrite.rewrite_inject_builtin_constr import RewriteInjectBuiltinsConstr
+from .rewrite.rewrite_remove_type_stuff import RewriteRemoveTypeStuff
 from .rewrite.rewrite_tuple_assign import RewriteTupleAssign
 from .optimize.optimize_remove_pass import OptimizeRemovePass
 from .optimize.optimize_remove_deadvars import OptimizeRemoveDeadvars
@@ -290,14 +291,6 @@ class UPLCCompiler(CompilingNodeTransformer):
         assert isinstance(
             node.targets[0], Name
         ), "Assignments to other things then names are not supported"
-        if (
-            isinstance(node.value.typ, UnionType)
-            or isinstance(node.value.typ, ListType)
-            or isinstance(node.value.typ, DictType)
-            or isinstance(node.value.typ, AnyType)
-        ):
-            # this type does not have a constructor and the constructor can hence not be passed on
-            return self.visit_sequence([])
         compiled_e = self.visit(node.value)
         # (\{STATEMONAD} -> (\x -> if (x ==b {self.visit(node.targets[0])}) then ({compiled_e} {STATEMONAD}) else ({STATEMONAD} x)))
         varname = node.targets[0].id
@@ -672,6 +665,7 @@ def compile(prog: AST):
         AggressiveTypeInferencer,
         # Rewrites that circumvent the type inference or use its results
         RewriteInjectBuiltinsConstr,
+        RewriteRemoveTypeStuff,
     ]
     for s in rewrite_steps:
         prog = s().visit(prog)
